# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from placebrain_contracts import auth_pb2 as auth__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in auth_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AuthServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Register = channel.unary_unary(
                '/auth.AuthService/Register',
                request_serializer=auth__pb2.RegisterRequest.SerializeToString,
                response_deserializer=auth__pb2.RegisterResponse.FromString,
                _registered_method=True)
        self.Login = channel.unary_unary(
                '/auth.AuthService/Login',
                request_serializer=auth__pb2.LoginRequest.SerializeToString,
                response_deserializer=auth__pb2.LoginResponse.FromString,
                _registered_method=True)
        self.RefreshTokens = channel.unary_unary(
                '/auth.AuthService/RefreshTokens',
                request_serializer=auth__pb2.RefreshTokensRequest.SerializeToString,
                response_deserializer=auth__pb2.RefreshTokensResponse.FromString,
                _registered_method=True)
        self.Logout = channel.unary_unary(
                '/auth.AuthService/Logout',
                request_serializer=auth__pb2.LogoutRequest.SerializeToString,
                response_deserializer=auth__pb2.LogoutResponse.FromString,
                _registered_method=True)
        self.GetMe = channel.unary_unary(
                '/auth.AuthService/GetMe',
                request_serializer=auth__pb2.GetMeRequest.SerializeToString,
                response_deserializer=auth__pb2.GetMeResponse.FromString,
                _registered_method=True)
        self.GetUserByEmail = channel.unary_unary(
                '/auth.AuthService/GetUserByEmail',
                request_serializer=auth__pb2.GetUserByEmailRequest.SerializeToString,
                response_deserializer=auth__pb2.GetUserByEmailResponse.FromString,
                _registered_method=True)
        self.ValidateToken = channel.unary_unary(
                '/auth.AuthService/ValidateToken',
                request_serializer=auth__pb2.ValidateTokenRequest.SerializeToString,
                response_deserializer=auth__pb2.ValidateTokenResponse.FromString,
                _registered_method=True)
        self.SendOtp = channel.unary_unary(
                '/auth.AuthService/SendOtp',
                request_serializer=auth__pb2.SendOtpRequest.SerializeToString,
                response_deserializer=auth__pb2.SendOtpResponse.FromString,
                _registered_method=True)
        self.VerifyOtp = channel.unary_unary(
                '/auth.AuthService/VerifyOtp',
                request_serializer=auth__pb2.VerifyOtpRequest.SerializeToString,
                response_deserializer=auth__pb2.VerifyOtpResponse.FromString,
                _registered_method=True)


class AuthServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Register(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshTokens(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Logout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserByEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendOtp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyOtp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Register': grpc.unary_unary_rpc_method_handler(
                    servicer.Register,
                    request_deserializer=auth__pb2.RegisterRequest.FromString,
                    response_serializer=auth__pb2.RegisterResponse.SerializeToString,
            ),
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=auth__pb2.LoginRequest.FromString,
                    response_serializer=auth__pb2.LoginResponse.SerializeToString,
            ),
            'RefreshTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshTokens,
                    request_deserializer=auth__pb2.RefreshTokensRequest.FromString,
                    response_serializer=auth__pb2.RefreshTokensResponse.SerializeToString,
            ),
            'Logout': grpc.unary_unary_rpc_method_handler(
                    servicer.Logout,
                    request_deserializer=auth__pb2.LogoutRequest.FromString,
                    response_serializer=auth__pb2.LogoutResponse.SerializeToString,
            ),
            'GetMe': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMe,
                    request_deserializer=auth__pb2.GetMeRequest.FromString,
                    response_serializer=auth__pb2.GetMeResponse.SerializeToString,
            ),
            'GetUserByEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserByEmail,
                    request_deserializer=auth__pb2.GetUserByEmailRequest.FromString,
                    response_serializer=auth__pb2.GetUserByEmailResponse.SerializeToString,
            ),
            'ValidateToken': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateToken,
                    request_deserializer=auth__pb2.ValidateTokenRequest.FromString,
                    response_serializer=auth__pb2.ValidateTokenResponse.SerializeToString,
            ),
            'SendOtp': grpc.unary_unary_rpc_method_handler(
                    servicer.SendOtp,
                    request_deserializer=auth__pb2.SendOtpRequest.FromString,
                    response_serializer=auth__pb2.SendOtpResponse.SerializeToString,
            ),
            'VerifyOtp': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyOtp,
                    request_deserializer=auth__pb2.VerifyOtpRequest.FromString,
                    response_serializer=auth__pb2.VerifyOtpResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'auth.AuthService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('auth.AuthService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AuthService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.AuthService/Register',
            auth__pb2.RegisterRequest.SerializeToString,
            auth__pb2.RegisterResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.AuthService/Login',
            auth__pb2.LoginRequest.SerializeToString,
            auth__pb2.LoginResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RefreshTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.AuthService/RefreshTokens',
            auth__pb2.RefreshTokensRequest.SerializeToString,
            auth__pb2.RefreshTokensResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Logout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.AuthService/Logout',
            auth__pb2.LogoutRequest.SerializeToString,
            auth__pb2.LogoutResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.AuthService/GetMe',
            auth__pb2.GetMeRequest.SerializeToString,
            auth__pb2.GetMeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUserByEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.AuthService/GetUserByEmail',
            auth__pb2.GetUserByEmailRequest.SerializeToString,
            auth__pb2.GetUserByEmailResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidateToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.AuthService/ValidateToken',
            auth__pb2.ValidateTokenRequest.SerializeToString,
            auth__pb2.ValidateTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendOtp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.AuthService/SendOtp',
            auth__pb2.SendOtpRequest.SerializeToString,
            auth__pb2.SendOtpResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VerifyOtp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/auth.AuthService/VerifyOtp',
            auth__pb2.VerifyOtpRequest.SerializeToString,
            auth__pb2.VerifyOtpResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import devices_pb2
import grpc
import grpc.aio
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class DevicesServiceStub:
    @typing.overload
    def __new__(cls, channel: grpc.Channel) -> DevicesServiceStub: ...
    @typing.overload
    def __new__(cls, channel: grpc.aio.Channel) -> DevicesServiceAsyncStub: ...
    CreateDevice: grpc.UnaryUnaryMultiCallable[devices_pb2.CreateDeviceRequest, devices_pb2.CreateDeviceResponse]
    """Devices CRUD"""
    GetDevice: grpc.UnaryUnaryMultiCallable[devices_pb2.GetDeviceRequest, devices_pb2.GetDeviceResponse]
    ListDevices: grpc.UnaryUnaryMultiCallable[devices_pb2.ListDevicesRequest, devices_pb2.ListDevicesResponse]
    UpdateDevice: grpc.UnaryUnaryMultiCallable[devices_pb2.UpdateDeviceRequest, devices_pb2.UpdateDeviceResponse]
    DeleteDevice: grpc.UnaryUnaryMultiCallable[devices_pb2.DeleteDeviceRequest, devices_pb2.DeleteDeviceResponse]
    RegenerateDeviceToken: grpc.UnaryUnaryMultiCallable[devices_pb2.RegenerateDeviceTokenRequest, devices_pb2.RegenerateDeviceTokenResponse]
    CreateSensor: grpc.UnaryUnaryMultiCallable[devices_pb2.CreateSensorRequest, devices_pb2.CreateSensorResponse]
    """Sensors CRUD"""
    ListSensors: grpc.UnaryUnaryMultiCallable[devices_pb2.ListSensorsRequest, devices_pb2.ListSensorsResponse]
    UpdateSensor: grpc.UnaryUnaryMultiCallable[devices_pb2.UpdateSensorRequest, devices_pb2.UpdateSensorResponse]
    DeleteSensor: grpc.UnaryUnaryMultiCallable[devices_pb2.DeleteSensorRequest, devices_pb2.DeleteSensorResponse]
    SetThreshold: grpc.UnaryUnaryMultiCallable[devices_pb2.SetThresholdRequest, devices_pb2.SetThresholdResponse]
    """Sensor Thresholds"""
    ListThresholds: grpc.UnaryUnaryMultiCallable[devices_pb2.ListThresholdsRequest, devices_pb2.ListThresholdsResponse]
    DeleteThreshold: grpc.UnaryUnaryMultiCallable[devices_pb2.DeleteThresholdRequest, devices_pb2.DeleteThresholdResponse]
    GetSensorThresholds: grpc.UnaryUnaryMultiCallable[devices_pb2.GetSensorThresholdsRequest, devices_pb2.GetSensorThresholdsResponse]
    CreateActuator: grpc.UnaryUnaryMultiCallable[devices_pb2.CreateActuatorRequest, devices_pb2.CreateActuatorResponse]
    """Actuators CRUD"""
    ListActuators: grpc.UnaryUnaryMultiCallable[devices_pb2.ListActuatorsRequest, devices_pb2.ListActuatorsResponse]
    UpdateActuator: grpc.UnaryUnaryMultiCallable[devices_pb2.UpdateActuatorRequest, devices_pb2.UpdateActuatorResponse]
    DeleteActuator: grpc.UnaryUnaryMultiCallable[devices_pb2.DeleteActuatorRequest, devices_pb2.DeleteActuatorResponse]
    SendCommand: grpc.UnaryUnaryMultiCallable[devices_pb2.SendCommandRequest, devices_pb2.SendCommandResponse]
    """Commands"""
    AuthenticateDevice: grpc.UnaryUnaryMultiCallable[devices_pb2.AuthenticateDeviceRequest, devices_pb2.AuthenticateDeviceResponse]
    """MQTT auth (internal, for gateway webhook)"""
    CheckDeviceAcl: grpc.UnaryUnaryMultiCallable[devices_pb2.CheckDeviceAclRequest, devices_pb2.CheckDeviceAclResponse]
    GenerateMqttCredentials: grpc.UnaryUnaryMultiCallable[devices_pb2.GenerateMqttCredentialsRequest, devices_pb2.GenerateMqttCredentialsResponse]
    """MQTT credentials for frontend users"""
    UpdateDeviceStatus: grpc.UnaryUnaryMultiCallable[devices_pb2.UpdateDeviceStatusRequest, devices_pb2.UpdateDeviceStatusResponse]
    """Device status (for collector)"""
    DeleteDevicesByPlace: grpc.UnaryUnaryMultiCallable[devices_pb2.DeleteDevicesByPlaceRequest, devices_pb2.DeleteDevicesByPlaceResponse]
    """Internal: delete all devices by place (for gateway cascade)"""
    InvalidateMqttCredentials: grpc.UnaryUnaryMultiCallable[devices_pb2.InvalidateMqttCredentialsRequest, devices_pb2.InvalidateMqttCredentialsResponse]
    """Internal: invalidate cached MQTT credentials (for gateway)"""
    GetAllThresholds: grpc.UnaryUnaryMultiCallable[devices_pb2.GetAllThresholdsRequest, devices_pb2.GetAllThresholdsResponse]
    """Internal: all thresholds for collector cache"""

@typing.type_check_only
class DevicesServiceAsyncStub(DevicesServiceStub):
    def __init__(self, channel: grpc.aio.Channel) -> None: ...
    CreateDevice: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.CreateDeviceRequest, devices_pb2.CreateDeviceResponse]  # type: ignore[assignment]
    """Devices CRUD"""
    GetDevice: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.GetDeviceRequest, devices_pb2.GetDeviceResponse]  # type: ignore[assignment]
    ListDevices: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.ListDevicesRequest, devices_pb2.ListDevicesResponse]  # type: ignore[assignment]
    UpdateDevice: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.UpdateDeviceRequest, devices_pb2.UpdateDeviceResponse]  # type: ignore[assignment]
    DeleteDevice: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.DeleteDeviceRequest, devices_pb2.DeleteDeviceResponse]  # type: ignore[assignment]
    RegenerateDeviceToken: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.RegenerateDeviceTokenRequest, devices_pb2.RegenerateDeviceTokenResponse]  # type: ignore[assignment]
    CreateSensor: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.CreateSensorRequest, devices_pb2.CreateSensorResponse]  # type: ignore[assignment]
    """Sensors CRUD"""
    ListSensors: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.ListSensorsRequest, devices_pb2.ListSensorsResponse]  # type: ignore[assignment]
    UpdateSensor: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.UpdateSensorRequest, devices_pb2.UpdateSensorResponse]  # type: ignore[assignment]
    DeleteSensor: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.DeleteSensorRequest, devices_pb2.DeleteSensorResponse]  # type: ignore[assignment]
    SetThreshold: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.SetThresholdRequest, devices_pb2.SetThresholdResponse]  # type: ignore[assignment]
    """Sensor Thresholds"""
    ListThresholds: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.ListThresholdsRequest, devices_pb2.ListThresholdsResponse]  # type: ignore[assignment]
    DeleteThreshold: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.DeleteThresholdRequest, devices_pb2.DeleteThresholdResponse]  # type: ignore[assignment]
    GetSensorThresholds: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.GetSensorThresholdsRequest, devices_pb2.GetSensorThresholdsResponse]  # type: ignore[assignment]
    CreateActuator: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.CreateActuatorRequest, devices_pb2.CreateActuatorResponse]  # type: ignore[assignment]
    """Actuators CRUD"""
    ListActuators: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.ListActuatorsRequest, devices_pb2.ListActuatorsResponse]  # type: ignore[assignment]
    UpdateActuator: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.UpdateActuatorRequest, devices_pb2.UpdateActuatorResponse]  # type: ignore[assignment]
    DeleteActuator: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.DeleteActuatorRequest, devices_pb2.DeleteActuatorResponse]  # type: ignore[assignment]
    SendCommand: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.SendCommandRequest, devices_pb2.SendCommandResponse]  # type: ignore[assignment]
    """Commands"""
    AuthenticateDevice: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.AuthenticateDeviceRequest, devices_pb2.AuthenticateDeviceResponse]  # type: ignore[assignment]
    """MQTT auth (internal, for gateway webhook)"""
    CheckDeviceAcl: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.CheckDeviceAclRequest, devices_pb2.CheckDeviceAclResponse]  # type: ignore[assignment]
    GenerateMqttCredentials: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.GenerateMqttCredentialsRequest, devices_pb2.GenerateMqttCredentialsResponse]  # type: ignore[assignment]
    """MQTT credentials for frontend users"""
    UpdateDeviceStatus: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.UpdateDeviceStatusRequest, devices_pb2.UpdateDeviceStatusResponse]  # type: ignore[assignment]
    """Device status (for collector)"""
    DeleteDevicesByPlace: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.DeleteDevicesByPlaceRequest, devices_pb2.DeleteDevicesByPlaceResponse]  # type: ignore[assignment]
    """Internal: delete all devices by place (for gateway cascade)"""
    InvalidateMqttCredentials: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.InvalidateMqttCredentialsRequest, devices_pb2.InvalidateMqttCredentialsResponse]  # type: ignore[assignment]
    """Internal: invalidate cached MQTT credentials (for gateway)"""
    GetAllThresholds: grpc.aio.UnaryUnaryMultiCallable[devices_pb2.GetAllThresholdsRequest, devices_pb2.GetAllThresholdsResponse]  # type: ignore[assignment]
    """Internal: all thresholds for collector cache"""

class DevicesServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateDevice(
        self,
        request: devices_pb2.CreateDeviceRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.CreateDeviceResponse, collections.abc.Awaitable[devices_pb2.CreateDeviceResponse]]:
        """Devices CRUD"""

    @abc.abstractmethod
    def GetDevice(
        self,
        request: devices_pb2.GetDeviceRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.GetDeviceResponse, collections.abc.Awaitable[devices_pb2.GetDeviceResponse]]: ...

    @abc.abstractmethod
    def ListDevices(
        self,
        request: devices_pb2.ListDevicesRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.ListDevicesResponse, collections.abc.Awaitable[devices_pb2.ListDevicesResponse]]: ...

    @abc.abstractmethod
    def UpdateDevice(
        self,
        request: devices_pb2.UpdateDeviceRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.UpdateDeviceResponse, collections.abc.Awaitable[devices_pb2.UpdateDeviceResponse]]: ...

    @abc.abstractmethod
    def DeleteDevice(
        self,
        request: devices_pb2.DeleteDeviceRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.DeleteDeviceResponse, collections.abc.Awaitable[devices_pb2.DeleteDeviceResponse]]: ...

    @abc.abstractmethod
    def RegenerateDeviceToken(
        self,
        request: devices_pb2.RegenerateDeviceTokenRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.RegenerateDeviceTokenResponse, collections.abc.Awaitable[devices_pb2.RegenerateDeviceTokenResponse]]: ...

    @abc.abstractmethod
    def CreateSensor(
        self,
        request: devices_pb2.CreateSensorRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.CreateSensorResponse, collections.abc.Awaitable[devices_pb2.CreateSensorResponse]]:
        """Sensors CRUD"""

    @abc.abstractmethod
    def ListSensors(
        self,
        request: devices_pb2.ListSensorsRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.ListSensorsResponse, collections.abc.Awaitable[devices_pb2.ListSensorsResponse]]: ...

    @abc.abstractmethod
    def UpdateSensor(
        self,
        request: devices_pb2.UpdateSensorRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.UpdateSensorResponse, collections.abc.Awaitable[devices_pb2.UpdateSensorResponse]]: ...

    @abc.abstractmethod
    def DeleteSensor(
        self,
        request: devices_pb2.DeleteSensorRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.DeleteSensorResponse, collections.abc.Awaitable[devices_pb2.DeleteSensorResponse]]: ...

    @abc.abstractmethod
    def SetThreshold(
        self,
        request: devices_pb2.SetThresholdRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.SetThresholdResponse, collections.abc.Awaitable[devices_pb2.SetThresholdResponse]]:
        """Sensor Thresholds"""

    @abc.abstractmethod
    def ListThresholds(
        self,
        request: devices_pb2.ListThresholdsRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.ListThresholdsResponse, collections.abc.Awaitable[devices_pb2.ListThresholdsResponse]]: ...

    @abc.abstractmethod
    def DeleteThreshold(
        self,
        request: devices_pb2.DeleteThresholdRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.DeleteThresholdResponse, collections.abc.Awaitable[devices_pb2.DeleteThresholdResponse]]: ...

    @abc.abstractmethod
    def GetSensorThresholds(
        self,
        request: devices_pb2.GetSensorThresholdsRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.GetSensorThresholdsResponse, collections.abc.Awaitable[devices_pb2.GetSensorThresholdsResponse]]: ...

    @abc.abstractmethod
    def CreateActuator(
        self,
        request: devices_pb2.CreateActuatorRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.CreateActuatorResponse, collections.abc.Awaitable[devices_pb2.CreateActuatorResponse]]:
        """Actuators CRUD"""

    @abc.abstractmethod
    def ListActuators(
        self,
        request: devices_pb2.ListActuatorsRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.ListActuatorsResponse, collections.abc.Awaitable[devices_pb2.ListActuatorsResponse]]: ...

    @abc.abstractmethod
    def UpdateActuator(
        self,
        request: devices_pb2.UpdateActuatorRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.UpdateActuatorResponse, collections.abc.Awaitable[devices_pb2.UpdateActuatorResponse]]: ...

    @abc.abstractmethod
    def DeleteActuator(
        self,
        request: devices_pb2.DeleteActuatorRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.DeleteActuatorResponse, collections.abc.Awaitable[devices_pb2.DeleteActuatorResponse]]: ...

    @abc.abstractmethod
    def SendCommand(
        self,
        request: devices_pb2.SendCommandRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.SendCommandResponse, collections.abc.Awaitable[devices_pb2.SendCommandResponse]]:
        """Commands"""

    @abc.abstractmethod
    def AuthenticateDevice(
        self,
        request: devices_pb2.AuthenticateDeviceRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.AuthenticateDeviceResponse, collections.abc.Awaitable[devices_pb2.AuthenticateDeviceResponse]]:
        """MQTT auth (internal, for gateway webhook)"""

    @abc.abstractmethod
    def CheckDeviceAcl(
        self,
        request: devices_pb2.CheckDeviceAclRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.CheckDeviceAclResponse, collections.abc.Awaitable[devices_pb2.CheckDeviceAclResponse]]: ...

    @abc.abstractmethod
    def GenerateMqttCredentials(
        self,
        request: devices_pb2.GenerateMqttCredentialsRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.GenerateMqttCredentialsResponse, collections.abc.Awaitable[devices_pb2.GenerateMqttCredentialsResponse]]:
        """MQTT credentials for frontend users"""

    @abc.abstractmethod
    def UpdateDeviceStatus(
        self,
        request: devices_pb2.UpdateDeviceStatusRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.UpdateDeviceStatusResponse, collections.abc.Awaitable[devices_pb2.UpdateDeviceStatusResponse]]:
        """Device status (for collector)"""

    @abc.abstractmethod
    def DeleteDevicesByPlace(
        self,
        request: devices_pb2.DeleteDevicesByPlaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.DeleteDevicesByPlaceResponse, collections.abc.Awaitable[devices_pb2.DeleteDevicesByPlaceResponse]]:
        """Internal: delete all devices by place (for gateway cascade)"""

    @abc.abstractmethod
    def InvalidateMqttCredentials(
        self,
        request: devices_pb2.InvalidateMqttCredentialsRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.InvalidateMqttCredentialsResponse, collections.abc.Awaitable[devices_pb2.InvalidateMqttCredentialsResponse]]:
        """Internal: invalidate cached MQTT credentials (for gateway)"""

    @abc.abstractmethod
    def GetAllThresholds(
        self,
        request: devices_pb2.GetAllThresholdsRequest,
        context: _ServicerContext,
    ) -> typing.Union[devices_pb2.GetAllThresholdsResponse, collections.abc.Awaitable[devices_pb2.GetAllThresholdsResponse]]:
        """Internal: all thresholds for collector cache"""

def add_DevicesServiceServicer_to_server(servicer: DevicesServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: places.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'places.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cplaces.proto\x12\x06places\"H\n\x12\x43reatePlaceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\'\n\x13\x43reatePlaceResponse\x12\x10\n\x08place_id\x18\x01 \x01(\t\"4\n\x0fGetPlaceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\"h\n\x10GetPlaceResponse\x12\x10\n\x08place_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1f\n\tuser_role\x18\x04 \x01(\x0e\x32\x0c.places.Role\"$\n\x11ListPlacesRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\":\n\x12ListPlacesResponse\x12$\n\x06places\x18\x01 \x03(\x0b\x32\x14.places.PlaceSummary\"d\n\x0cPlaceSummary\x12\x10\n\x08place_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1f\n\tuser_role\x18\x04 \x01(\x0e\x32\x0c.places.Role\"Z\n\x12UpdatePlaceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\'\n\x13UpdatePlaceResponse\x12\x10\n\x08place_id\x18\x01 \x01(\t\"7\n\x12\x44\x65letePlaceRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\"&\n\x13\x44\x65letePlaceResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"i\n\x10\x41\x64\x64MemberRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x16\n\x0etarget_user_id\x18\x03 \x01(\t\x12\x1a\n\x04role\x18\x04 \x01(\x0e\x32\x0c.places.Role\"$\n\x11\x41\x64\x64MemberResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"P\n\x13RemoveMemberRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x16\n\x0etarget_user_id\x18\x03 \x01(\t\"\'\n\x14RemoveMemberResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"p\n\x17UpdateMemberRoleRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\x12\x16\n\x0etarget_user_id\x18\x03 \x01(\t\x12\x1a\n\x04role\x18\x04 \x01(\x0e\x32\x0c.places.Role\"+\n\x18UpdateMemberRoleResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"7\n\x12ListMembersRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x10\n\x08place_id\x18\x02 \x01(\t\":\n\x13ListMembersResponse\x12#\n\x07members\x18\x01 \x03(\x0b\x32\x12.places.MemberInfo\"9\n\nMemberInfo\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x1a\n\x04role\x18\x02 \x01(\x0e\x32\x0c.places.Role*M\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\x0e\n\nROLE_OWNER\x10\x01\x12\x0e\n\nROLE_ADMIN\x10\x02\x12\x0f\n\x0bROLE_VIEWER\x10\x03\x32\x97\x05\n\rPlacesService\x12\x46\n\x0b\x43reatePlace\x12\x1a.places.CreatePlaceRequest\x1a\x1b.places.CreatePlaceResponse\x12=\n\x08GetPlace\x12\x17.places.GetPlaceRequest\x1a\x18.places.GetPlaceResponse\x12\x43\n\nListPlaces\x12\x19.places.ListPlacesRequest\x1a\x1a.places.ListPlacesResponse\x12\x46\n\x0bUpdatePlace\x12\x1a.places.UpdatePlaceRequest\x1a\x1b.places.UpdatePlaceResponse\x12\x46\n\x0b\x44\x65letePlace\x12\x1a.places.DeletePlaceRequest\x1a\x1b.places.DeletePlaceResponse\x12@\n\tAddMember\x12\x18.places.AddMemberRequest\x1a\x19.places.AddMemberResponse\x12I\n\x0cRemoveMember\x12\x1b.places.RemoveMemberRequest\x1a\x1c.places.RemoveMemberResponse\x12U\n\x10UpdateMemberRole\x12\x1f.places.UpdateMemberRoleRequest\x1a .places.UpdateMemberRoleResponse\x12\x46\n\x0bListMembers\x12\x1a.places.ListMembersRequest\x1a\x1b.places.ListMembersResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'places_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ROLE']._serialized_start=1332
  _globals['_ROLE']._serialized_end=1409
  _globals['_CREATEPLACEREQUEST']._serialized_start=24
  _globals['_CREATEPLACEREQUEST']._serialized_end=96
  _globals['_CREATEPLACERESPONSE']._serialized_start=98
  _globals['_CREATEPLACERESPONSE']._serialized_end=137
  _globals['_GETPLACEREQUEST']._serialized_start=139
  _globals['_GETPLACEREQUEST']._serialized_end=191
  _globals['_GETPLACERESPONSE']._serialized_start=193
  _globals['_GETPLACERESPONSE']._serialized_end=297
  _globals['_LISTPLACESREQUEST']._serialized_start=299
  _globals['_LISTPLACESREQUEST']._serialized_end=335
  _globals['_LISTPLACESRESPONSE']._serialized_start=337
  _globals['_LISTPLACESRESPONSE']._serialized_end=395
  _globals['_PLACESUMMARY']._serialized_start=397
  _globals['_PLACESUMMARY']._serialized_end=497
  _globals['_UPDATEPLACEREQUEST']._serialized_start=499
  _globals['_UPDATEPLACEREQUEST']._serialized_end=589
  _globals['_UPDATEPLACERESPONSE']._serialized_start=591
  _globals['_UPDATEPLACERESPONSE']._serialized_end=630
  _globals['_DELETEPLACEREQUEST']._serialized_start=632
  _globals['_DELETEPLACEREQUEST']._serialized_end=687
  _globals['_DELETEPLACERESPONSE']._serialized_start=689
  _globals['_DELETEPLACERESPONSE']._serialized_end=727
  _globals['_ADDMEMBERREQUEST']._serialized_start=729
  _globals['_ADDMEMBERREQUEST']._serialized_end=834
  _globals['_ADDMEMBERRESPONSE']._serialized_start=836
  _globals['_ADDMEMBERRESPONSE']._serialized_end=872
  _globals['_REMOVEMEMBERREQUEST']._serialized_start=874
  _globals['_REMOVEMEMBERREQUEST']._serialized_end=954
  _globals['_REMOVEMEMBERRESPONSE']._serialized_start=956
  _globals['_REMOVEMEMBERRESPONSE']._serialized_end=995
  _globals['_UPDATEMEMBERROLEREQUEST']._serialized_start=997
  _globals['_UPDATEMEMBERROLEREQUEST']._serialized_end=1109
  _globals['_UPDATEMEMBERROLERESPONSE']._serialized_start=1111
  _globals['_UPDATEMEMBERROLERESPONSE']._serialized_end=1154
  _globals['_LISTMEMBERSREQUEST']._serialized_start=1156
  _globals['_LISTMEMBERSREQUEST']._serialized_end=1211
  _globals['_LISTMEMBERSRESPONSE']._serialized_start=1213
  _globals['_LISTMEMBERSRESPONSE']._serialized_end=1271
  _globals['_MEMBERINFO']._serialized_start=1273
  _globals['_MEMBERINFO']._serialized_end=1330
  _globals['_PLACESSERVICE']._serialized_start=1412
  _globals['_PLACESSERVICE']._serialized_end=2075
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from placebrain_contracts import devices_pb2 as devices__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in devices_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class DevicesServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDevice = channel.unary_unary(
                '/devices.DevicesService/CreateDevice',
                request_serializer=devices__pb2.CreateDeviceRequest.SerializeToString,
                response_deserializer=devices__pb2.CreateDeviceResponse.FromString,
                _registered_method=True)
        self.GetDevice = channel.unary_unary(
                '/devices.DevicesService/GetDevice',
                request_serializer=devices__pb2.GetDeviceRequest.SerializeToString,
                response_deserializer=devices__pb2.GetDeviceResponse.FromString,
                _registered_method=True)
        self.ListDevices = channel.unary_unary(
                '/devices.DevicesService/ListDevices',
                request_serializer=devices__pb2.ListDevicesRequest.SerializeToString,
                response_deserializer=devices__pb2.ListDevicesResponse.FromString,
                _registered_method=True)
        self.UpdateDevice = channel.unary_unary(
                '/devices.DevicesService/UpdateDevice',
                request_serializer=devices__pb2.UpdateDeviceRequest.SerializeToString,
                response_deserializer=devices__pb2.UpdateDeviceResponse.FromString,
                _registered_method=True)
        self.DeleteDevice = channel.unary_unary(
                '/devices.DevicesService/DeleteDevice',
                request_serializer=devices__pb2.DeleteDeviceRequest.SerializeToString,
                response_deserializer=devices__pb2.DeleteDeviceResponse.FromString,
                _registered_method=True)
        self.RegenerateDeviceToken = channel.unary_unary(
                '/devices.DevicesService/RegenerateDeviceToken',
                request_serializer=devices__pb2.RegenerateDeviceTokenRequest.SerializeToString,
                response_deserializer=devices__pb2.RegenerateDeviceTokenResponse.FromString,
                _registered_method=True)
        self.CreateSensor = channel.unary_unary(
                '/devices.DevicesService/CreateSensor',
                request_serializer=devices__pb2.CreateSensorRequest.SerializeToString,
                response_deserializer=devices__pb2.CreateSensorResponse.FromString,
                _registered_method=True)
        self.ListSensors = channel.unary_unary(
                '/devices.DevicesService/ListSensors',
                request_serializer=devices__pb2.ListSensorsRequest.SerializeToString,
                response_deserializer=devices__pb2.ListSensorsResponse.FromString,
                _registered_method=True)
        self.UpdateSensor = channel.unary_unary(
                '/devices.DevicesService/UpdateSensor',
                request_serializer=devices__pb2.UpdateSensorRequest.SerializeToString,
                response_deserializer=devices__pb2.UpdateSensorResponse.FromString,
                _registered_method=True)
        self.DeleteSensor = channel.unary_unary(
                '/devices.DevicesService/DeleteSensor',
                request_serializer=devices__pb2.DeleteSensorRequest.SerializeToString,
                response_deserializer=devices__pb2.DeleteSensorResponse.FromString,
                _registered_method=True)
        self.SetThreshold = channel.unary_unary(
                '/devices.DevicesService/SetThreshold',
                request_serializer=devices__pb2.SetThresholdRequest.SerializeToString,
                response_deserializer=devices__pb2.SetThresholdResponse.FromString,
                _registered_method=True)
        self.ListThresholds = channel.unary_unary(
                '/devices.DevicesService/ListThresholds',
                request_serializer=devices__pb2.ListThresholdsRequest.SerializeToString,
                response_deserializer=devices__pb2.ListThresholdsResponse.FromString,
                _registered_method=True)
        self.DeleteThreshold = channel.unary_unary(
                '/devices.DevicesService/DeleteThreshold',
                request_serializer=devices__pb2.DeleteThresholdRequest.SerializeToString,
                response_deserializer=devices__pb2.DeleteThresholdResponse.FromString,
                _registered_method=True)
        self.GetSensorThresholds = channel.unary_unary(
                '/devices.DevicesService/GetSensorThresholds',
                request_serializer=devices__pb2.GetSensorThresholdsRequest.SerializeToString,
                response_deserializer=devices__pb2.GetSensorThresholdsResponse.FromString,
                _registered_method=True)
        self.CreateActuator = channel.unary_unary(
                '/devices.DevicesService/CreateActuator',
                request_serializer=devices__pb2.CreateActuatorRequest.SerializeToString,
                response_deserializer=devices__pb2.CreateActuatorResponse.FromString,
                _registered_method=True)
        self.ListActuators = channel.unary_unary(
                '/devices.DevicesService/ListActuators',
                request_serializer=devices__pb2.ListActuatorsRequest.SerializeToString,
                response_deserializer=devices__pb2.ListActuatorsResponse.FromString,
                _registered_method=True)
        self.UpdateActuator = channel.unary_unary(
                '/devices.DevicesService/UpdateActuator',
                request_serializer=devices__pb2.UpdateActuatorRequest.SerializeToString,
                response_deserializer=devices__pb2.UpdateActuatorResponse.FromString,
                _registered_method=True)
        self.DeleteActuator = channel.unary_unary(
                '/devices.DevicesService/DeleteActuator',
                request_serializer=devices__pb2.DeleteActuatorRequest.SerializeToString,
                response_deserializer=devices__pb2.DeleteActuatorResponse.FromString,
                _registered_method=True)
        self.SendCommand = channel.unary_unary(
                '/devices.DevicesService/SendCommand',
                request_serializer=devices__pb2.SendCommandRequest.SerializeToString,
                response_deserializer=devices__pb2.SendCommandResponse.FromString,
                _registered_method=True)
        self.AuthenticateDevice = channel.unary_unary(
                '/devices.DevicesService/AuthenticateDevice',
                request_serializer=devices__pb2.AuthenticateDeviceRequest.SerializeToString,
                response_deserializer=devices__pb2.AuthenticateDeviceResponse.FromString,
                _registered_method=True)
        self.CheckDeviceAcl = channel.unary_unary(
                '/devices.DevicesService/CheckDeviceAcl',
                request_serializer=devices__pb2.CheckDeviceAclRequest.SerializeToString,
                response_deserializer=devices__pb2.CheckDeviceAclResponse.FromString,
                _registered_method=True)
        self.GenerateMqttCredentials = channel.unary_unary(
                '/devices.DevicesService/GenerateMqttCredentials',
                request_serializer=devices__pb2.GenerateMqttCredentialsRequest.SerializeToString,
                response_deserializer=devices__pb2.GenerateMqttCredentialsResponse.FromString,
                _registered_method=True)
        self.UpdateDeviceStatus = channel.unary_unary(
                '/devices.DevicesService/UpdateDeviceStatus',
                request_serializer=devices__pb2.UpdateDeviceStatusRequest.SerializeToString,
                response_deserializer=devices__pb2.UpdateDeviceStatusResponse.FromString,
                _registered_method=True)
        self.DeleteDevicesByPlace = channel.unary_unary(
                '/devices.DevicesService/DeleteDevicesByPlace',
                request_serializer=devices__pb2.DeleteDevicesByPlaceRequest.SerializeToString,
                response_deserializer=devices__pb2.DeleteDevicesByPlaceResponse.FromString,
                _registered_method=True)
        self.InvalidateMqttCredentials = channel.unary_unary(
                '/devices.DevicesService/InvalidateMqttCredentials',
                request_serializer=devices__pb2.InvalidateMqttCredentialsRequest.SerializeToString,
                response_deserializer=devices__pb2.InvalidateMqttCredentialsResponse.FromString,
                _registered_method=True)
        self.GetAllThresholds = channel.unary_unary(
                '/devices.DevicesService/GetAllThresholds',
                request_serializer=devices__pb2.GetAllThresholdsRequest.SerializeToString,
                response_deserializer=devices__pb2.GetAllThresholdsResponse.FromString,
                _registered_method=True)


class DevicesServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateDevice(self, request, context):
        """Devices CRUD
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDevices(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDevice(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegenerateDeviceToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSensor(self, request, context):
        """Sensors CRUD
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSensors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSensor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSensor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetThreshold(self, request, context):
        """Sensor Thresholds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListThresholds(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteThreshold(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSensorThresholds(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateActuator(self, request, context):
        """Actuators CRUD
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListActuators(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateActuator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteActuator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendCommand(self, request, context):
        """Commands
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthenticateDevice(self, request, context):
        """MQTT auth (internal, for gateway webhook)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckDeviceAcl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateMqttCredentials(self, request, context):
        """MQTT credentials for frontend users
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDeviceStatus(self, request, context):
        """Device status (for collector)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDevicesByPlace(self, request, context):
        """Internal: delete all devices by place (for gateway cascade)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InvalidateMqttCredentials(self, request, context):
        """Internal: invalidate cached MQTT credentials (for gateway)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllThresholds(self, request, context):
        """Internal: all thresholds for collector cache
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DevicesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDevice,
                    request_deserializer=devices__pb2.CreateDeviceRequest.FromString,
                    response_serializer=devices__pb2.CreateDeviceResponse.SerializeToString,
            ),
            'GetDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDevice,
                    request_deserializer=devices__pb2.GetDeviceRequest.FromString,
                    response_serializer=devices__pb2.GetDeviceResponse.SerializeToString,
            ),
            'ListDevices': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDevices,
                    request_deserializer=devices__pb2.ListDevicesRequest.FromString,
                    response_serializer=devices__pb2.ListDevicesResponse.SerializeToString,
            ),
            'UpdateDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDevice,
                    request_deserializer=devices__pb2.UpdateDeviceRequest.FromString,
                    response_serializer=devices__pb2.UpdateDeviceResponse.SerializeToString,
            ),
            'DeleteDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDevice,
                    request_deserializer=devices__pb2.DeleteDeviceRequest.FromString,
                    response_serializer=devices__pb2.DeleteDeviceResponse.SerializeToString,
            ),
            'RegenerateDeviceToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RegenerateDeviceToken,
                    request_deserializer=devices__pb2.RegenerateDeviceTokenRequest.FromString,
                    response_serializer=devices__pb2.RegenerateDeviceTokenResponse.SerializeToString,
            ),
            'CreateSensor': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSensor,
                    request_deserializer=devices__pb2.CreateSensorRequest.FromString,
                    response_serializer=devices__pb2.CreateSensorResponse.SerializeToString,
            ),
            'ListSensors': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSensors,
                    request_deserializer=devices__pb2.ListSensorsRequest.FromString,
                    response_serializer=devices__pb2.ListSensorsResponse.SerializeToString,
            ),
            'UpdateSensor': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSensor,
                    request_deserializer=devices__pb2.UpdateSensorRequest.FromString,
                    response_serializer=devices__pb2.UpdateSensorResponse.SerializeToString,
            ),
            'DeleteSensor': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSensor,
                    request_deserializer=devices__pb2.DeleteSensorRequest.FromString,
                    response_serializer=devices__pb2.DeleteSensorResponse.SerializeToString,
            ),
            'SetThreshold': grpc.unary_unary_rpc_method_handler(
                    servicer.SetThreshold,
                    request_deserializer=devices__pb2.SetThresholdRequest.FromString,
                    response_serializer=devices__pb2.SetThresholdResponse.SerializeToString,
            ),
            'ListThresholds': grpc.unary_unary_rpc_method_handler(
                    servicer.ListThresholds,
                    request_deserializer=devices__pb2.ListThresholdsRequest.FromString,
                    response_serializer=devices__pb2.ListThresholdsResponse.SerializeToString,
            ),
            'DeleteThreshold': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteThreshold,
                    request_deserializer=devices__pb2.DeleteThresholdRequest.FromString,
                    response_serializer=devices__pb2.DeleteThresholdResponse.SerializeToString,
            ),
            'GetSensorThresholds': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSensorThresholds,
                    request_deserializer=devices__pb2.GetSensorThresholdsRequest.FromString,
                    response_serializer=devices__pb2.GetSensorThresholdsResponse.SerializeToString,
            ),
            'CreateActuator': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateActuator,
                    request_deserializer=devices__pb2.CreateActuatorRequest.FromString,
                    response_serializer=devices__pb2.CreateActuatorResponse.SerializeToString,
            ),
            'ListActuators': grpc.unary_unary_rpc_method_handler(
                    servicer.ListActuators,
                    request_deserializer=devices__pb2.ListActuatorsRequest.FromString,
                    response_serializer=devices__pb2.ListActuatorsResponse.SerializeToString,
            ),
            'UpdateActuator': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateActuator,
                    request_deserializer=devices__pb2.UpdateActuatorRequest.FromString,
                    response_serializer=devices__pb2.UpdateActuatorResponse.SerializeToString,
            ),
            'DeleteActuator': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteActuator,
                    request_deserializer=devices__pb2.DeleteActuatorRequest.FromString,
                    response_serializer=devices__pb2.DeleteActuatorResponse.SerializeToString,
            ),
            'SendCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.SendCommand,
                    request_deserializer=devices__pb2.SendCommandRequest.FromString,
                    response_serializer=devices__pb2.SendCommandResponse.SerializeToString,
            ),
            'AuthenticateDevice': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthenticateDevice,
                    request_deserializer=devices__pb2.AuthenticateDeviceRequest.FromString,
                    response_serializer=devices__pb2.AuthenticateDeviceResponse.SerializeToString,
            ),
            'CheckDeviceAcl': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckDeviceAcl,
                    request_deserializer=devices__pb2.CheckDeviceAclRequest.FromString,
                    response_serializer=devices__pb2.CheckDeviceAclResponse.SerializeToString,
            ),
            'GenerateMqttCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateMqttCredentials,
                    request_deserializer=devices__pb2.GenerateMqttCredentialsRequest.FromString,
                    response_serializer=devices__pb2.GenerateMqttCredentialsResponse.SerializeToString,
            ),
            'UpdateDeviceStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDeviceStatus,
                    request_deserializer=devices__pb2.UpdateDeviceStatusRequest.FromString,
                    response_serializer=devices__pb2.UpdateDeviceStatusResponse.SerializeToString,
            ),
            'DeleteDevicesByPlace': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDevicesByPlace,
                    request_deserializer=devices__pb2.DeleteDevicesByPlaceRequest.FromString,
                    response_serializer=devices__pb2.DeleteDevicesByPlaceResponse.SerializeToString,
            ),
            'InvalidateMqttCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.InvalidateMqttCredentials,
                    request_deserializer=devices__pb2.InvalidateMqttCredentialsRequest.FromString,
                    response_serializer=devices__pb2.InvalidateMqttCredentialsResponse.SerializeToString,
            ),
            'GetAllThresholds': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllThresholds,
                    request_deserializer=devices__pb2.GetAllThresholdsRequest.FromString,
                    response_serializer=devices__pb2.GetAllThresholdsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'devices.DevicesService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('devices.DevicesService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DevicesService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/CreateDevice',
            devices__pb2.CreateDeviceRequest.SerializeToString,
            devices__pb2.CreateDeviceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/GetDevice',
            devices__pb2.GetDeviceRequest.SerializeToString,
            devices__pb2.GetDeviceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDevices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/ListDevices',
            devices__pb2.ListDevicesRequest.SerializeToString,
            devices__pb2.ListDevicesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/UpdateDevice',
            devices__pb2.UpdateDeviceRequest.SerializeToString,
            devices__pb2.UpdateDeviceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/DeleteDevice',
            devices__pb2.DeleteDeviceRequest.SerializeToString,
            devices__pb2.DeleteDeviceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegenerateDeviceToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/RegenerateDeviceToken',
            devices__pb2.RegenerateDeviceTokenRequest.SerializeToString,
            devices__pb2.RegenerateDeviceTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateSensor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/CreateSensor',
            devices__pb2.CreateSensorRequest.SerializeToString,
            devices__pb2.CreateSensorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSensors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/ListSensors',
            devices__pb2.ListSensorsRequest.SerializeToString,
            devices__pb2.ListSensorsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateSensor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/UpdateSensor',
            devices__pb2.UpdateSensorRequest.SerializeToString,
            devices__pb2.UpdateSensorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteSensor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/DeleteSensor',
            devices__pb2.DeleteSensorRequest.SerializeToString,
            devices__pb2.DeleteSensorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetThreshold(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/SetThreshold',
            devices__pb2.SetThresholdRequest.SerializeToString,
            devices__pb2.SetThresholdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListThresholds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/ListThresholds',
            devices__pb2.ListThresholdsRequest.SerializeToString,
            devices__pb2.ListThresholdsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteThreshold(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/DeleteThreshold',
            devices__pb2.DeleteThresholdRequest.SerializeToString,
            devices__pb2.DeleteThresholdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSensorThresholds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/GetSensorThresholds',
            devices__pb2.GetSensorThresholdsRequest.SerializeToString,
            devices__pb2.GetSensorThresholdsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateActuator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/CreateActuator',
            devices__pb2.CreateActuatorRequest.SerializeToString,
            devices__pb2.CreateActuatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListActuators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/ListActuators',
            devices__pb2.ListActuatorsRequest.SerializeToString,
            devices__pb2.ListActuatorsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateActuator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/UpdateActuator',
            devices__pb2.UpdateActuatorRequest.SerializeToString,
            devices__pb2.UpdateActuatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteActuator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/DeleteActuator',
            devices__pb2.DeleteActuatorRequest.SerializeToString,
            devices__pb2.DeleteActuatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/SendCommand',
            devices__pb2.SendCommandRequest.SerializeToString,
            devices__pb2.SendCommandResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AuthenticateDevice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/AuthenticateDevice',
            devices__pb2.AuthenticateDeviceRequest.SerializeToString,
            devices__pb2.AuthenticateDeviceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CheckDeviceAcl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/CheckDeviceAcl',
            devices__pb2.CheckDeviceAclRequest.SerializeToString,
            devices__pb2.CheckDeviceAclResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GenerateMqttCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/GenerateMqttCredentials',
            devices__pb2.GenerateMqttCredentialsRequest.SerializeToString,
            devices__pb2.GenerateMqttCredentialsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDeviceStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/UpdateDeviceStatus',
            devices__pb2.UpdateDeviceStatusRequest.SerializeToString,
            devices__pb2.UpdateDeviceStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDevicesByPlace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/DeleteDevicesByPlace',
            devices__pb2.DeleteDevicesByPlaceRequest.SerializeToString,
            devices__pb2.DeleteDevicesByPlaceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InvalidateMqttCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/InvalidateMqttCredentials',
            devices__pb2.InvalidateMqttCredentialsRequest.SerializeToString,
            devices__pb2.InvalidateMqttCredentialsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAllThresholds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/devices.DevicesService/GetAllThresholds',
            devices__pb2.GetAllThresholdsRequest.SerializeToString,
            devices__pb2.GetAllThresholdsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from placebrain_contracts import places_pb2 as places__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in places_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class PlacesServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreatePlace = channel.unary_unary(
                '/places.PlacesService/CreatePlace',
                request_serializer=places__pb2.CreatePlaceRequest.SerializeToString,
                response_deserializer=places__pb2.CreatePlaceResponse.FromString,
                _registered_method=True)
        self.GetPlace = channel.unary_unary(
                '/places.PlacesService/GetPlace',
                request_serializer=places__pb2.GetPlaceRequest.SerializeToString,
                response_deserializer=places__pb2.GetPlaceResponse.FromString,
                _registered_method=True)
        self.ListPlaces = channel.unary_unary(
                '/places.PlacesService/ListPlaces',
                request_serializer=places__pb2.ListPlacesRequest.SerializeToString,
                response_deserializer=places__pb2.ListPlacesResponse.FromString,
                _registered_method=True)
        self.UpdatePlace = channel.unary_unary(
                '/places.PlacesService/UpdatePlace',
                request_serializer=places__pb2.UpdatePlaceRequest.SerializeToString,
                response_deserializer=places__pb2.UpdatePlaceResponse.FromString,
                _registered_method=True)
        self.DeletePlace = channel.unary_unary(
                '/places.PlacesService/DeletePlace',
                request_serializer=places__pb2.DeletePlaceRequest.SerializeToString,
                response_deserializer=places__pb2.DeletePlaceResponse.FromString,
                _registered_method=True)
        self.AddMember = channel.unary_unary(
                '/places.PlacesService/AddMember',
                request_serializer=places__pb2.AddMemberRequest.SerializeToString,
                response_deserializer=places__pb2.AddMemberResponse.FromString,
                _registered_method=True)
        self.RemoveMember = channel.unary_unary(
                '/places.PlacesService/RemoveMember',
                request_serializer=places__pb2.RemoveMemberRequest.SerializeToString,
                response_deserializer=places__pb2.RemoveMemberResponse.FromString,
                _registered_method=True)
        self.UpdateMemberRole = channel.unary_unary(
                '/places.PlacesService/UpdateMemberRole',
                request_serializer=places__pb2.UpdateMemberRoleRequest.SerializeToString,
                response_deserializer=places__pb2.UpdateMemberRoleResponse.FromString,
                _registered_method=True)
        self.ListMembers = channel.unary_unary(
                '/places.PlacesService/ListMembers',
                request_serializer=places__pb2.ListMembersRequest.SerializeToString,
                response_deserializer=places__pb2.ListMembersResponse.FromString,
                _registered_method=True)


class PlacesServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreatePlace(self, request, context):
        """Places CRUD
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPlaces(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePlace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePlace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddMember(self, request, context):
        """Members
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveMember(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMemberRole(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PlacesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreatePlace': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePlace,
                    request_deserializer=places__pb2.CreatePlaceRequest.FromString,
                    response_serializer=places__pb2.CreatePlaceResponse.SerializeToString,
            ),
            'GetPlace': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPlace,
                    request_deserializer=places__pb2.GetPlaceRequest.FromString,
                    response_serializer=places__pb2.GetPlaceResponse.SerializeToString,
            ),
            'ListPlaces': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPlaces,
                    request_deserializer=places__pb2.ListPlacesRequest.FromString,
                    response_serializer=places__pb2.ListPlacesResponse.SerializeToString,
            ),
            'UpdatePlace': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePlace,
                    request_deserializer=places__pb2.UpdatePlaceRequest.FromString,
                    response_serializer=places__pb2.UpdatePlaceResponse.SerializeToString,
            ),
            'DeletePlace': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePlace,
                    request_deserializer=places__pb2.DeletePlaceRequest.FromString,
                    response_serializer=places__pb2.DeletePlaceResponse.SerializeToString,
            ),
            'AddMember': grpc.unary_unary_rpc_method_handler(
                    servicer.AddMember,
                    request_deserializer=places__pb2.AddMemberRequest.FromString,
                    response_serializer=places__pb2.AddMemberResponse.SerializeToString,
            ),
            'RemoveMember': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveMember,
                    request_deserializer=places__pb2.RemoveMemberRequest.FromString,
                    response_serializer=places__pb2.RemoveMemberResponse.SerializeToString,
            ),
            'UpdateMemberRole': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMemberRole,
                    request_deserializer=places__pb2.UpdateMemberRoleRequest.FromString,
                    response_serializer=places__pb2.UpdateMemberRoleResponse.SerializeToString,
            ),
            'ListMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMembers,
                    request_deserializer=places__pb2.ListMembersRequest.FromString,
                    response_serializer=places__pb2.ListMembersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'places.PlacesService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('places.PlacesService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PlacesService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreatePlace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/places.PlacesService/CreatePlace',
            places__pb2.CreatePlaceRequest.SerializeToString,
            places__pb2.CreatePlaceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPlace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/places.PlacesService/GetPlace',
            places__pb2.GetPlaceRequest.SerializeToString,
            places__pb2.GetPlaceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPlaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/places.PlacesService/ListPlaces',
            places__pb2.ListPlacesRequest.SerializeToString,
            places__pb2.ListPlacesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdatePlace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/places.PlacesService/UpdatePlace',
            places__pb2.UpdatePlaceRequest.SerializeToString,
            places__pb2.UpdatePlaceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeletePlace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/places.PlacesService/DeletePlace',
            places__pb2.DeletePlaceRequest.SerializeToString,
            places__pb2.DeletePlaceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddMember(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/places.PlacesService/AddMember',
            places__pb2.AddMemberRequest.SerializeToString,
            places__pb2.AddMemberResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveMember(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/places.PlacesService/RemoveMember',
            places__pb2.RemoveMemberRequest.SerializeToString,
            places__pb2.RemoveMemberResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateMemberRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/places.PlacesService/UpdateMemberRole',
            places__pb2.UpdateMemberRoleRequest.SerializeToString,
            places__pb2.UpdateMemberRoleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/places.PlacesService/ListMembers',
            places__pb2.ListMembersRequest.SerializeToString,
            places__pb2.ListMembersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RegisterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    username: builtins.str
    email: builtins.str
    password: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str = ...,
        email: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["email", b"email", "password", b"password", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RegisterRequest: typing_extensions.TypeAlias = RegisterRequest

@typing.final
class RegisterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RegisterResponse: typing_extensions.TypeAlias = RegisterResponse

@typing.final
class LoginRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAIL_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    email: builtins.str
    password: builtins.str
    def __init__(
        self,
        *,
        email: builtins.str = ...,
        password: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["email", b"email", "password", b"password"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___LoginRequest: typing_extensions.TypeAlias = LoginRequest

@typing.final
class LoginResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    access_token: builtins.str
    refresh_token: builtins.str
    def __init__(
        self,
        *,
        access_token: builtins.str = ...,
        refresh_token: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["access_token", b"access_token", "refresh_token", b"refresh_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___LoginResponse: typing_extensions.TypeAlias = LoginResponse

@typing.final
class RefreshTokensRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    refresh_token: builtins.str
    def __init__(
        self,
        *,
        refresh_token: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["refresh_token", b"refresh_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RefreshTokensRequest: typing_extensions.TypeAlias = RefreshTokensRequest

@typing.final
class RefreshTokensResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    access_token: builtins.str
    refresh_token: builtins.str
    def __init__(
        self,
        *,
        access_token: builtins.str = ...,
        refresh_token: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["access_token", b"access_token", "refresh_token", b"refresh_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RefreshTokensResponse: typing_extensions.TypeAlias = RefreshTokensResponse

@typing.final
class LogoutRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    refresh_token: builtins.str
    def __init__(
        self,
        *,
        refresh_token: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["refresh_token", b"refresh_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___LogoutRequest: typing_extensions.TypeAlias = LogoutRequest

@typing.final
class LogoutResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___LogoutResponse: typing_extensions.TypeAlias = LogoutResponse

@typing.final
class GetMeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetMeRequest: typing_extensions.TypeAlias = GetMeRequest

@typing.final
class GetMeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    IS_VERIFIED_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    username: builtins.str
    email: builtins.str
    is_verified: builtins.bool
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        username: builtins.str = ...,
        email: builtins.str = ...,
        is_verified: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["email", b"email", "is_verified", b"is_verified", "user_id", b"user_id", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetMeResponse: typing_extensions.TypeAlias = GetMeResponse

@typing.final
class GetUserByEmailRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAIL_FIELD_NUMBER: builtins.int
    email: builtins.str
    def __init__(
        self,
        *,
        email: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["email", b"email"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetUserByEmailRequest: typing_extensions.TypeAlias = GetUserByEmailRequest

@typing.final
class GetUserByEmailResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    username: builtins.str
    email: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        username: builtins.str = ...,
        email: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["email", b"email", "user_id", b"user_id", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetUserByEmailResponse: typing_extensions.TypeAlias = GetUserByEmailResponse

@typing.final
class ValidateTokenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    access_token: builtins.str
    def __init__(
        self,
        *,
        access_token: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["access_token", b"access_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ValidateTokenRequest: typing_extensions.TypeAlias = ValidateTokenRequest

@typing.final
class ValidateTokenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    valid: builtins.bool
    user_id: builtins.str
    email: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        valid: builtins.bool = ...,
        user_id: builtins.str = ...,
        email: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["email", b"email", "user_id", b"user_id", "username", b"username", "valid", b"valid"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ValidateTokenResponse: typing_extensions.TypeAlias = ValidateTokenResponse

@typing.final
class SendOtpRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAIL_FIELD_NUMBER: builtins.int
    email: builtins.str
    def __init__(
        self,
        *,
        email: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["email", b"email"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendOtpRequest: typing_extensions.TypeAlias = SendOtpRequest

@typing.final
class SendOtpResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendOtpResponse: typing_extensions.TypeAlias = SendOtpResponse

@typing.final
class VerifyOtpRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAIL_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    email: builtins.str
    code: builtins.str
    def __init__(
        self,
        *,
        email: builtins.str = ...,
        code: builtins.str = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["code", b"code", "email", b"email"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___VerifyOtpRequest: typing_extensions.TypeAlias = VerifyOtpRequest

@typing.final
class VerifyOtpResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    success: builtins.bool
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["success", b"success"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___VerifyOtpResponse: typing_extensions.TypeAlias = VerifyOtpResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import places_pb2
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class PlacesServiceStub:
    @typing.overload
    def __new__(cls, channel: grpc.Channel) -> PlacesServiceStub: ...
    @typing.overload
    def __new__(cls, channel: grpc.aio.Channel) -> PlacesServiceAsyncStub: ...
    CreatePlace: grpc.UnaryUnaryMultiCallable[places_pb2.CreatePlaceRequest, places_pb2.CreatePlaceResponse]
    """Places CRUD"""
    GetPlace: grpc.UnaryUnaryMultiCallable[places_pb2.GetPlaceRequest, places_pb2.GetPlaceResponse]
    ListPlaces: grpc.UnaryUnaryMultiCallable[places_pb2.ListPlacesRequest, places_pb2.ListPlacesResponse]
    UpdatePlace: grpc.UnaryUnaryMultiCallable[places_pb2.UpdatePlaceRequest, places_pb2.UpdatePlaceResponse]
    DeletePlace: grpc.UnaryUnaryMultiCallable[places_pb2.DeletePlaceRequest, places_pb2.DeletePlaceResponse]
    AddMember: grpc.UnaryUnaryMultiCallable[places_pb2.AddMemberRequest, places_pb2.AddMemberResponse]
    """Members"""
    RemoveMember: grpc.UnaryUnaryMultiCallable[places_pb2.RemoveMemberRequest, places_pb2.RemoveMemberResponse]
    UpdateMemberRole: grpc.UnaryUnaryMultiCallable[places_pb2.UpdateMemberRoleRequest, places_pb2.UpdateMemberRoleResponse]
    ListMembers: grpc.UnaryUnaryMultiCallable[places_pb2.ListMembersRequest, places_pb2.ListMembersResponse]

@typing.type_check_only
class PlacesServiceAsyncStub(PlacesServiceStub):
    def __init__(self, channel: grpc.aio.Channel) -> None: ...
    CreatePlace: grpc.aio.UnaryUnaryMultiCallable[places_pb2.CreatePlaceRequest, places_pb2.CreatePlaceResponse]  # type: ignore[assignment]
    """Places CRUD"""
    GetPlace: grpc.aio.UnaryUnaryMultiCallable[places_pb2.GetPlaceRequest, places_pb2.GetPlaceResponse]  # type: ignore[assignment]
    ListPlaces: grpc.aio.UnaryUnaryMultiCallable[places_pb2.ListPlacesRequest, places_pb2.ListPlacesResponse]  # type: ignore[assignment]
    UpdatePlace: grpc.aio.UnaryUnaryMultiCallable[places_pb2.UpdatePlaceRequest, places_pb2.UpdatePlaceResponse]  # type: ignore[assignment]
    DeletePlace: grpc.aio.UnaryUnaryMultiCallable[places_pb2.DeletePlaceRequest, places_pb2.DeletePlaceResponse]  # type: ignore[assignment]
    AddMember: grpc.aio.UnaryUnaryMultiCallable[places_pb2.AddMemberRequest, places_pb2.AddMemberResponse]  # type: ignore[assignment]
    """Members"""
    RemoveMember: grpc.aio.UnaryUnaryMultiCallable[places_pb2.RemoveMemberRequest, places_pb2.RemoveMemberResponse]  # type: ignore[assignment]
    UpdateMemberRole: grpc.aio.UnaryUnaryMultiCallable[places_pb2.UpdateMemberRoleRequest, places_pb2.UpdateMemberRoleResponse]  # type: ignore[assignment]
    ListMembers: grpc.aio.UnaryUnaryMultiCallable[places_pb2.ListMembersRequest, places_pb2.ListMembersResponse]  # type: ignore[assignment]

class PlacesServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreatePlace(
        self,
        request: places_pb2.CreatePlaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.CreatePlaceResponse, collections.abc.Awaitable[places_pb2.CreatePlaceResponse]]:
        """Places CRUD"""

    @abc.abstractmethod
    def GetPlace(
        self,
        request: places_pb2.GetPlaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.GetPlaceResponse, collections.abc.Awaitable[places_pb2.GetPlaceResponse]]: ...

    @abc.abstractmethod
    def ListPlaces(
        self,
        request: places_pb2.ListPlacesRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.ListPlacesResponse, collections.abc.Awaitable[places_pb2.ListPlacesResponse]]: ...

    @abc.abstractmethod
    def UpdatePlace(
        self,
        request: places_pb2.UpdatePlaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.UpdatePlaceResponse, collections.abc.Awaitable[places_pb2.UpdatePlaceResponse]]: ...

    @abc.abstractmethod
    def DeletePlace(
        self,
        request: places_pb2.DeletePlaceRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.DeletePlaceResponse, collections.abc.Awaitable[places_pb2.DeletePlaceResponse]]: ...

    @abc.abstractmethod
    def AddMember(
        self,
        request: places_pb2.AddMemberRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.AddMemberResponse, collections.abc.Awaitable[places_pb2.AddMemberResponse]]:
        """Members"""

    @abc.abstractmethod
    def RemoveMember(
        self,
        request: places_pb2.RemoveMemberRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.RemoveMemberResponse, collections.abc.Awaitable[places_pb2.RemoveMemberResponse]]: ...

    @abc.abstractmethod
    def UpdateMemberRole(
        self,
        request: places_pb2.UpdateMemberRoleRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.UpdateMemberRoleResponse, collections.abc.Awaitable[places_pb2.UpdateMemberRoleResponse]]: ...

    @abc.abstractmethod
    def ListMembers(
        self,
        request: places_pb2.ListMembersRequest,
        context: _ServicerContext,
    ) -> typing.Union[places_pb2.ListMembersResponse, collections.abc.Awaitable[places_pb2.ListMembersResponse]]: ...

def add_PlacesServiceServicer_to_server(servicer: PlacesServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
